module.exports = defineTest({
	description: 'renders named export declarations',
	options: { output: { name: 'bundle' } }
});
